==> vtk-8.1.2-1-aarch64.pkg.tar.xz: vtk/vtkXMLWriter.java <==
// java wrapper for vtkXMLWriter object
//

package vtk;
import vtk.*;

public class vtkXMLWriter extends vtkAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetByteOrder_2(int id0);
  public void SetByteOrder(int id0)
    { SetByteOrder_2(id0); }

  private native int GetByteOrder_3();
  public int GetByteOrder()
    { return GetByteOrder_3(); }

  private native void SetByteOrderToBigEndian_4();
  public void SetByteOrderToBigEndian()
    { SetByteOrderToBigEndian_4(); }

  private native void SetByteOrderToLittleEndian_5();
  public void SetByteOrderToLittleEndian()
    { SetByteOrderToLittleEndian_5(); }

  private native void SetHeaderType_6(int id0);
  public void SetHeaderType(int id0)
    { SetHeaderType_6(id0); }

  private native int GetHeaderType_7();
  public int GetHeaderType()
    { return GetHeaderType_7(); }

  private native void SetHeaderTypeToUInt32_8();
  public void SetHeaderTypeToUInt32()
    { SetHeaderTypeToUInt32_8(); }

  private native void SetHeaderTypeToUInt64_9();
  public void SetHeaderTypeToUInt64()
    { SetHeaderTypeToUInt64_9(); }

  private native void SetIdType_10(int id0);
  public void SetIdType(int id0)
    { SetIdType_10(id0); }

  private native int GetIdType_11();
  public int GetIdType()
    { return GetIdType_11(); }

  private native void SetIdTypeToInt32_12();
  public void SetIdTypeToInt32()
    { SetIdTypeToInt32_12(); }

  private native void SetIdTypeToInt64_13();
  public void SetIdTypeToInt64()
    { SetIdTypeToInt64_13(); }

  private native void SetFileName_14(String id0);
  public void SetFileName(String id0)
    { SetFileName_14(id0); }

  private native String GetFileName_15();
  public String GetFileName()
    { return GetFileName_15(); }

  private native void SetWriteToOutputString_16(int id0);
  public void SetWriteToOutputString(int id0)
    { SetWriteToOutputString_16(id0); }

  private native int GetWriteToOutputString_17();
  public int GetWriteToOutputString()
    { return GetWriteToOutputString_17(); }

  private native void WriteToOutputStringOn_18();
  public void WriteToOutputStringOn()
    { WriteToOutputStringOn_18(); }

  private native void WriteToOutputStringOff_19();
  public void WriteToOutputStringOff()
    { WriteToOutputStringOff_19(); }

  private native String GetOutputString_20();
  public String GetOutputString()
    { return GetOutputString_20(); }

  private native void SetCompressor_21(vtkDataCompressor id0);
  public void SetCompressor(vtkDataCompressor id0)
    { SetCompressor_21(id0); }

  private native long GetCompressor_22();
  public vtkDataCompressor GetCompressor() {
    long temp = GetCompressor_22();

    if (temp == 0) return null;
    return (vtkDataCompressor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetCompressorType_23(int id0);
  public void SetCompressorType(int id0)
    { SetCompressorType_23(id0); }

  private native void SetCompressorTypeToNone_24();
  public void SetCompressorTypeToNone()
    { SetCompressorTypeToNone_24(); }

  private native void SetCompressorTypeToLZ4_25();
  public void SetCompressorTypeToLZ4()
    { SetCompressorTypeToLZ4_25(); }

  private native void SetCompressorTypeToZLib_26();
  public void SetCompressorTypeToZLib()
    { SetCompressorTypeToZLib_26(); }

  private native void SetDataMode_27(int id0);
  public void SetDataMode(int id0)
    { SetDataMode_27(id0); }

  private native int GetDataMode_28();
  public int GetDataMode()
    { return GetDataMode_28(); }

  private native void SetDataModeToAscii_29();
  public void SetDataModeToAscii()
    { SetDataModeToAscii_29(); }

  private native void SetDataModeToBinary_30();
  public void SetDataModeToBinary()
    { SetDataModeToBinary_30(); }

  private native void SetDataModeToAppended_31();
  public void SetDataModeToAppended()
    { SetDataModeToAppended_31(); }

  private native void SetEncodeAppendedData_32(int id0);
  public void SetEncodeAppendedData(int id0)
    { SetEncodeAppendedData_32(id0); }

  private native int GetEncodeAppendedData_33();
  public int GetEncodeAppendedData()
    { return GetEncodeAppendedData_33(); }

  private native void EncodeAppendedDataOn_34();
  public void EncodeAppendedDataOn()
    { EncodeAppendedDataOn_34(); }

  private native void EncodeAppendedDataOff_35();
  public void EncodeAppendedDataOff()
    { EncodeAppendedDataOff_35(); }

  private native void SetInputData_36(vtkDataObject id0);
  public void SetInputData(vtkDataObject id0)
    { SetInputData_36(id0); }

  private native void SetInputData_37(int id0,vtkDataObject id1);
  public void SetInputData(int id0,vtkDataObject id1)
    { SetInputData_37(id0,id1); }

  private native long GetInput_38(int id0);
  public vtkDataObject GetInput(int id0) {
    long temp = GetInput_38(id0);

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInput_39();
  public vtkDataObject GetInput() {
    long temp = GetInput_39();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native String GetDefaultFileExtension_40();
  public String GetDefaultFileExtension()
    { return GetDefaultFileExtension_40(); }

  private native int Write_41();
  public int Write()
    { return Write_41(); }

  private native int GetNumberOfTimeSteps_42();
  public int GetNumberOfTimeSteps()
    { return GetNumberOfTimeSteps_42(); }

  private native void SetNumberOfTimeSteps_43(int id0);
  public void SetNumberOfTimeSteps(int id0)
    { SetNumberOfTimeSteps_43(id0); }

  private native void Start_44();
  public void Start()
    { Start_44(); }

  private native void Stop_45();
  public void Stop()
    { Stop_45(); }

  private native void WriteNextTime_46(double id0);
  public void WriteNextTime(double id0)
    { WriteNextTime_46(id0); }

  public vtkXMLWriter() { super(); }

  public vtkXMLWriter(long id) { super(id); }

}

==> vtk-8.2.0-20-aarch64.pkg.tar.xz: vtk/vtkXMLWriter.java <==
// java wrapper for vtkXMLWriter object
//

package vtk;
import vtk.*;

public class vtkXMLWriter extends vtkAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetByteOrder_2(int id0);
  public void SetByteOrder(int id0)
    { SetByteOrder_2(id0); }

  private native int GetByteOrder_3();
  public int GetByteOrder()
    { return GetByteOrder_3(); }

  private native void SetByteOrderToBigEndian_4();
  public void SetByteOrderToBigEndian()
    { SetByteOrderToBigEndian_4(); }

  private native void SetByteOrderToLittleEndian_5();
  public void SetByteOrderToLittleEndian()
    { SetByteOrderToLittleEndian_5(); }

  private native void SetHeaderType_6(int id0);
  public void SetHeaderType(int id0)
    { SetHeaderType_6(id0); }

  private native int GetHeaderType_7();
  public int GetHeaderType()
    { return GetHeaderType_7(); }

  private native void SetHeaderTypeToUInt32_8();
  public void SetHeaderTypeToUInt32()
    { SetHeaderTypeToUInt32_8(); }

  private native void SetHeaderTypeToUInt64_9();
  public void SetHeaderTypeToUInt64()
    { SetHeaderTypeToUInt64_9(); }

  private native void SetIdType_10(int id0);
  public void SetIdType(int id0)
    { SetIdType_10(id0); }

  private native int GetIdType_11();
  public int GetIdType()
    { return GetIdType_11(); }

  private native void SetIdTypeToInt32_12();
  public void SetIdTypeToInt32()
    { SetIdTypeToInt32_12(); }

  private native void SetIdTypeToInt64_13();
  public void SetIdTypeToInt64()
    { SetIdTypeToInt64_13(); }

  private native void SetFileName_14(String id0);
  public void SetFileName(String id0)
    { SetFileName_14(id0); }

  private native String GetFileName_15();
  public String GetFileName()
    { return GetFileName_15(); }

  private native void SetWriteToOutputString_16(int id0);
  public void SetWriteToOutputString(int id0)
    { SetWriteToOutputString_16(id0); }

  private native int GetWriteToOutputString_17();
  public int GetWriteToOutputString()
    { return GetWriteToOutputString_17(); }

  private native void WriteToOutputStringOn_18();
  public void WriteToOutputStringOn()
    { WriteToOutputStringOn_18(); }

  private native void WriteToOutputStringOff_19();
  public void WriteToOutputStringOff()
    { WriteToOutputStringOff_19(); }

  private native String GetOutputString_20();
  public String GetOutputString()
    { return GetOutputString_20(); }

  private native void SetCompressor_21(vtkDataCompressor id0);
  public void SetCompressor(vtkDataCompressor id0)
    { SetCompressor_21(id0); }

  private native long GetCompressor_22();
  public vtkDataCompressor GetCompressor() {
    long temp = GetCompressor_22();

    if (temp == 0) return null;
    return (vtkDataCompressor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetCompressorType_23(int id0);
  public void SetCompressorType(int id0)
    { SetCompressorType_23(id0); }

  private native void SetCompressorTypeToNone_24();
  public void SetCompressorTypeToNone()
    { SetCompressorTypeToNone_24(); }

  private native void SetCompressorTypeToLZ4_25();
  public void SetCompressorTypeToLZ4()
    { SetCompressorTypeToLZ4_25(); }

  private native void SetCompressorTypeToZLib_26();
  public void SetCompressorTypeToZLib()
    { SetCompressorTypeToZLib_26(); }

  private native void SetCompressorTypeToLZMA_27();
  public void SetCompressorTypeToLZMA()
    { SetCompressorTypeToLZMA_27(); }

  private native void SetCompressionLevel_28(int id0);
  public void SetCompressionLevel(int id0)
    { SetCompressionLevel_28(id0); }

  private native int GetCompressionLevel_29();
  public int GetCompressionLevel()
    { return GetCompressionLevel_29(); }

  private native void SetDataMode_30(int id0);
  public void SetDataMode(int id0)
    { SetDataMode_30(id0); }

  private native int GetDataMode_31();
  public int GetDataMode()
    { return GetDataMode_31(); }

  private native void SetDataModeToAscii_32();
  public void SetDataModeToAscii()
    { SetDataModeToAscii_32(); }

  private native void SetDataModeToBinary_33();
  public void SetDataModeToBinary()
    { SetDataModeToBinary_33(); }

  private native void SetDataModeToAppended_34();
  public void SetDataModeToAppended()
    { SetDataModeToAppended_34(); }

  private native void SetEncodeAppendedData_35(int id0);
  public void SetEncodeAppendedData(int id0)
    { SetEncodeAppendedData_35(id0); }

  private native int GetEncodeAppendedData_36();
  public int GetEncodeAppendedData()
    { return GetEncodeAppendedData_36(); }

  private native void EncodeAppendedDataOn_37();
  public void EncodeAppendedDataOn()
    { EncodeAppendedDataOn_37(); }

  private native void EncodeAppendedDataOff_38();
  public void EncodeAppendedDataOff()
    { EncodeAppendedDataOff_38(); }

  private native void SetInputData_39(vtkDataObject id0);
  public void SetInputData(vtkDataObject id0)
    { SetInputData_39(id0); }

  private native void SetInputData_40(int id0,vtkDataObject id1);
  public void SetInputData(int id0,vtkDataObject id1)
    { SetInputData_40(id0,id1); }

  private native long GetInput_41(int id0);
  public vtkDataObject GetInput(int id0) {
    long temp = GetInput_41(id0);

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInput_42();
  public vtkDataObject GetInput() {
    long temp = GetInput_42();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native String GetDefaultFileExtension_43();
  public String GetDefaultFileExtension()
    { return GetDefaultFileExtension_43(); }

  private native int Write_44();
  public int Write()
    { return Write_44(); }

  private native int GetNumberOfTimeSteps_45();
  public int GetNumberOfTimeSteps()
    { return GetNumberOfTimeSteps_45(); }

  private native void SetNumberOfTimeSteps_46(int id0);
  public void SetNumberOfTimeSteps(int id0)
    { SetNumberOfTimeSteps_46(id0); }

  private native void Start_47();
  public void Start()
    { Start_47(); }

  private native void Stop_48();
  public void Stop()
    { Stop_48(); }

  private native void WriteNextTime_49(double id0);
  public void WriteNextTime(double id0)
    { WriteNextTime_49(id0); }

  public vtkXMLWriter() { super(); }

  public vtkXMLWriter(long id) { super(id); }

}
